const path = require('path');


const config = {
  projectName: 'fe_mp_all',
  date: '2019-6-4',
  designWidth: 750,
  deviceRatio: {
    '640': 2.34 / 2,
    '750': 1,
    '828': 1.81 / 2
  },
  sourceRoot: 'src',
  outputRoot: 'dist',
  plugins: {
    babel: {
      sourceMap: true,
      presets: [
        ['env', {
          modules: false
        }]
      ],
      plugins: [
        'transform-decorators-legacy',
        'transform-class-properties',
        'transform-object-rest-spread'
      ]
    }
  },
  alias: {
    '@/components': path.resolve(__dirname, '..', 'src/components'),
    '@/api': path.resolve(__dirname, '..', 'src/apiFetch'),
    '@/api1': path.resolve(__dirname, '..', 'src/api'),
    '@/host': path.resolve(__dirname, '..', 'src/config/host.js'),
    '@/mpConfig': path.resolve(__dirname, '..', 'src/config/mp_config.js'),
    '@/utils': path.resolve(__dirname, '..', 'src/common/js/utils.js'),
    '@/utilsDir': path.resolve(__dirname, '..', 'src/common/js'),
    '@/store': path.resolve(__dirname, '..', 'src/store'),
    '@/common': path.resolve(__dirname, '..', 'src/common'),
    '@/commonStyle': path.resolve(__dirname, '..', 'src/common/style/tjGlobal.scss')
  },
  defineConstants: {
  },
  copy: {
    patterns: [
      { from: 'src/config/index.js', to: 'dist/config/index.js'},
      { from: 'src/searchWidget', to: 'dist/searchWidget'},
    ],
    options: {}
  },
  weapp: {
    module: {
      postcss: {
        autoprefixer: {
          enable: true,
          config: {
            browsers: [
              'last 3 versions',
              'Android >= 4.1',
              'ios >= 8'
            ]
          }
        },
        pxtransform: {
          enable: true,
          config: {

          }
        },
        url: {
          enable: true,
          config: {
            limit: 10240 // 设定转换尺寸上限
          }
        },
        cssModules: {
          enable: false, // 默认为 false，如需使用 css modules 功能，则设为 true
          config: {
            namingPattern: 'module', // 转换模式，取值为 global/module
            generateScopedName: '[name]__[local]___[hash:base64:5]'
          }
        }
      }
    }
  },
  h5: {
    publicPath: '/',
    staticDirectory: 'static',
    module: {
      postcss: {
        autoprefixer: {
          enable: true,
          config: {
            browsers: [
              'last 3 versions',
              'Android >= 4.1',
              'ios >= 8'
            ]
          }
        },
        cssModules: {
          enable: false, // 默认为 false，如需使用 css modules 功能，则设为 true
          config: {
            namingPattern: 'module', // 转换模式，取值为 global/module
            generateScopedName: '[name]__[local]___[hash:base64:5]'
          }
        }
      }
    }
  }
}

module.exports = function (merge) {
  if (process.env.NODE_ENV === 'development') {
    return merge({}, config, require('./dev'))
  }
  return merge({}, config, require('./prod'))
}
