'use strict'


import Taro from '@tarojs/taro'

class Fetch$1 {
  /**
   * 构造器
   * @param {[type]} reqHandle 请求拦截方法
   * @param {[type]} resHandle 返回拦截方法
   * @param {number} httpReqLoadingCount 当前开启loading的请求数量
   */

  httpReqLoadingCount = 0

  constructor({
    resHandle,
    reqHandle
  }) {
    this.reqHandle = reqHandle
    this.resHandle = resHandle
  }
  /**
   * Post请求
   * @param  {[type]} url              [请求URL]
   * @param  {[type]} data             [post请求数据]
   * @param  {[type]} params           [url参数]
   * @param  {[type]} headers          [header自定义]
   * @param  {[type]} withCredentials  [设置是否跨域传输cookie]
   * @param  {[type]} [timeout=10000}] [过时时间]
   * @param  {[type]} [isLoading=false}] [是否开启loading，默认不开启]
   * @param  {[type]} [loadingDelayTime=200}] [loading延时出现时间，延迟时间内结束就不展示loading]
   * @param  {[type]} [loadingText=请稍候}] [loading提示文字]
   * @param  {[type]} [dataType=json}] [响应的数据格式，默认为json，非json选项不会自动被小程序parse]
   * @return {[type]}                  [{isSuccess,data,err}]
   */
  post(url, {
    data,
    params,
    headers={},
    withCredentials = false,
    timeout = 10000,
    isLoading = false,
    loadingDelayTime = 200,
    loadingText = '请稍候...',
    dataType = 'json',
  } = {}) {
    return this.http({
      url,
      method: 'post',
      data,
      params,
      headers,
      withCredentials,
      timeout,
      isLoading,
      loadingDelayTime,
      loadingText,
      dataType
    })
  }
  /**
   * Post请求
   * @param  {[type]} url              [请求URL]
   * @param  {[type]} data             [post请求数据]
   * @param  {[type]} params           [url参数]
   * @param  {[type]} headers          [header自定义]
   * @param  {[type]} withCredentials  [设置是否跨域传输cookie]
   * @param  {[type]} [timeout=10000}] [过时时间]
   * @param  {[type]} [isLoading=false}] [是否开启loading，默认不开启]
   * @param  {[type]} [loadingText=请稍候}] [loading提示文字]
   * @param  {[type]} [loadingDelayTime=300}] [loading延时出现时间，延迟时间内结束就不展示loading]
   * @param  {[type]} [dataType=json}] [响应的数据格式，默认为json，非json选项不会自动被小程序parse]
   * @return {[type]}                  [{isSuccess,data,err}]
   */
  get(url, {
    data,
    params,
    headers={},
    withCredentials = false,
    timeout = 10000,
    isLoading = false,
    loadingDelayTime = 300,
    loadingText = '请稍候...'
  } = {}) {
    return this.http({
      url,
      method: 'get',
      data,
      params,
      headers,
      withCredentials,
      timeout,
      isLoading,
      loadingText,
      loadingDelayTime
    })
  }
  http(options) {

    let loadingTimer = this.setLoading(options)
    // 增加接口请求的timespan
    options.params = options.params || {}
    // options.params._apitsp = new Date().getTime()
    if (this.reqHandle) {
      this.reqHandle(options)
    }
    return new Promise((resolve, reject) => {
      Taro.request({
        url: options.url + '?_apitsp=' + new Date().getTime(),
        data: options.params,
        method: options.method,
        dataType: options.dataType || 'json',
        header: options.headers,
        success: (res) => {
          if(res.statusCode === 200) {
            if (this.resHandle) {
              return this.resHandle(res.data, {
                resolve,
                reject
              }, options)
            }
            resolve(res.data)
          }
          else {
            reject({
              errorNo: -1000,
              errorMsg: '网络请求错误'
            })
          }      
        },
        fail: (err) => {
          if (err.response || err.request) {
            reject({
              errorNo: -1000,
              errorMsg: '网络请求错误'
            })
          } else {
            reject(err)
          }
        },
        complete: () => {
          if (options.isLoading) this.removeLoading(loadingTimer)
        }
      })
    })

  }
  /**
   * 设置Loading
   * @param  {[type]} [isLoading=false}] [是否开启loading，默认不开启]
   * @param  {[type]} [loadingDelayTime=300}] [loading延时出现时间，延迟时间内结束就不展示loading]
   * @param  {[type]} [loadingText=请稍候}] [loading提示文字]
   */
  setLoading({
    isLoading,
    loadingDelayTime,
    loadingText
  }) {
    if (isLoading) {
      return this.loadingTimer = setTimeout(() => {
        if (!this.httpReqLoadingCount) {
          Taro.showLoading({
            title: loadingText,
            mask: true
          })
        }
        this.httpReqLoadingCount++
      }, loadingDelayTime)
    }
  }
  /**
   * 删除loading
   * @param  {timer} [loadingTimer}] [定时器对象]
   */
  removeLoading(loadingTimer) {
    clearTimeout(loadingTimer)
    if (this.httpReqLoadingCount) this.httpReqLoadingCount--
    if (!this.httpReqLoadingCount) {
      Taro.hideLoading()
    }
  }
}

export default Fetch$1

if (!Promise.prototype.finally) {
  Promise.prototype.finally = function (callback) {
    let P = this.constructor;
    return this.then(
      value => P.resolve(callback()).then(() => value),
      reason => P.resolve(callback()).then(() => {
        throw reason
      })
    );
  };
}